Utilisez la commande d'interface de ligne de commande (CLI) update_consumer_group pour modifier les informations relatives à un groupe de consommateurs spécifié.
Syntaxe de la requête
aliyunlog log update_consumer_group --project=<value> --logstore=<value> --consumer_group=<value> [--timeout=<value>] [--in_order=<value>] [--access-id=<value>] [--access-key=<value>] [--sts-token=<value>] [--region-endpoint=<value>] [--client-name=<value>] [--jmes-filter=<value>] [--format-output=<value>] [--decode-output=<value>
Paramètres de la requête
Le tableau suivant décrit les paramètres obligatoires et spécifiques à cette commande.
Nom du paramètre | Type de données | Obligatoire | Exemple | Description |
--project | String | Oui | aliyun-test-project | Nom du projet. |
--logstore | String | Oui | logstore-a | Nom du Logstore. |
--consumer_group | String | Oui | consumer-group-1 | Nom du groupe de consommateurs. |
--timeout | Integer | Non | 360 | Délai d'expiration, en secondes. Les consommateurs envoient des signaux de maintien de connexion (heartbeats) périodiques à Log Service. Si aucun signal n'est reçu durant cette période, Log Service libère les ressources du consommateur. |
--in_order | Boolean | Non | true | Indique si les messages doivent être consommés dans l'ordre au sein d'un seul shard.
|
Pour plus d'informations sur les paramètres globaux de cette commande, consultez la rubrique Paramètres globaux.
Exemples
-
Exemple de requête
Modifiez le délai d'expiration du groupe de consommateurs
consumer-group-1en utilisant le compte par défaut.aliyunlog log update_consumer_group --project="aliyun-test-project" --logstore="logstore-a" --consumer_group="consumer-group-1" --timeout="360" --in_order=true -
Si la commande s'exécute avec succès, aucune réponse n'est renvoyée. Exécutez la commande suivante pour interroger le groupe de consommateurs.
aliyunlog log list_consumer_group --project="aliyun-test-project" --logstore="logstore-a"Le résultat suivant s'affiche :
[ { "name": "consumer-group-1", "order": true, "timeout": 360 } ]
Codes d'erreur
En cas de message d'erreur, consultez la documentation relative aux codes d'erreur pour cette opération d'API. Pour plus d'informations, voir Codes d'erreur.